@@ -1,7 +1,7 @@
 from setuptools import setup
 from setuptools.command.install import install
 from setuptools.command.sdist import sdist
-from distutils.command.build import build
+from setuptools.command.build import build
 import os
 import shutil
 
@@ -49,7 +49,7 @@ except ImportError:
 
 setup(
     name="notcurses",
-    version="3.0.7",
+    version="3.0.16",
     packages=['notcurses'],
     scripts=['notcurses-pydemo', 'ncdirect-pydemo'],
     package_dir={'': 'src'},
