@@ -35,6 +35,9 @@ rgba_blitter_default(const tinfo* tcache, ncscale_e scale){
   if(scale == NCSCALE_NONE || scale == NCSCALE_SCALE){
     return NCBLIT_2x1;
   }
+  if(tcache->caps.octants){
+    return NCBLIT_4x2;
+  }
   if(tcache->caps.sextants){
     return NCBLIT_3x2;
   }
