@@ -35,6 +35,9 @@ extern "C" {
 #include <wctype.h>
 #include <pthread.h>
 #include <stdbool.h>
+#ifndef __STDC_FORMAT_MACROS
+#define __STDC_FORMAT_MACROS
+#endif
 #include <inttypes.h>
 #include <unictype.h>
 #ifndef __MINGW32__
@@ -1284,9 +1287,6 @@ cell_set_blitquadrants(nccell* c, unsigned tl, unsigned tr, unsigned bl, unsigne
   c->channels = ((c->channels & ~NC_BLITTERSTACK_MASK) | newval);
 }
 
-// Destroy a plane and all its bound descendants.
-int ncplane_destroy_family(ncplane *ncp);
-
 // Extract the 32-bit background channel from a cell.
 static inline uint32_t
 cell_bchannel(const nccell* cl){
@@ -1355,9 +1355,7 @@ channels_blend(notcurses* nc, unsigned c1, unsigned c2, unsigned* blends,
     }
   }else if(ncchannel_default_p(c1) && ncchannel_default_p(c2)){
     // do nothing, leave as default
-  // intentional bitwise AND on the first condition, to eliminate the
-  // dependency due to C's short-circuit evaluation
-  }else if((ncchannel_palindex_p(c1) & ncchannel_palindex_p(c2)) &&
+  }else if((ncchannel_palindex_p(c1) && ncchannel_palindex_p(c2)) &&
            ncchannel_palindex(c1) == ncchannel_palindex(c2)){
     // do nothing, leave as palette
   }else{
@@ -1888,6 +1886,33 @@ int putenv_term(const char* termname) __attribute__ ((nonnull (1)));
 int set_loglevel_from_env(ncloglevel_e* loglevel)
   __attribute__ ((nonnull (1)));
 
+// glibc's _nl_normalize_charset() converts to lowercase, removing everything
+// but alnums. furthermore, "cs" is a valid prefix meaning "character set".
+static inline bool
+encoding_is_utf8(const char *enc){
+  if(tolower(enc[0]) == 'c' && tolower(enc[1]) == 's'){ // strncasecmp() isn't ansi/iso
+    enc += 2; // skip initial "cs" if present.
+  }
+  const char utfstr[] = "utf8";
+  const char* match = utfstr;
+  while(*enc){
+    if(isalnum(*enc)){ // we only care about alnums
+      if(tolower(*enc) != tolower(*match)){
+        return false;
+      }
+      ++match;
+    }
+    ++enc;
+  }
+  if(*match){
+    return false;
+  }
+  return true;
+}
+
+// tell ncmetric that utf8 is available. should be per-context, but isn't.
+void ncmetric_use_utf8(void);
+
 #undef API
 #undef ALLOC
 
